@@ -38,14 +38,14 @@ def run(number):
     play_dir = 'Posit'
     pdb_dir_list = [i for i in os.listdir(play_dir) if os.path.isdir(os.path.join(play_dir, i))]
 
-    old_dir_names = []
+    pdb_id_list = []
     for idx, pdb_dir in enumerate(pdb_dir_list):
         old_dir_name = os.path.join(play_dir, pdb_dir)
         new_dir_name = os.path.join(play_dir, 'Exercise_'+str(idx+1))
         answer.append(prepare_data(play_dir, pdb_dir))
         os.rename(old_dir_name, new_dir_name)
         # record PDB_ID
-        old_dir_names.append(old_dir_name)
+        pdb_id_list.append(pdb_dir)
 
     txt_list = []
 
@@ -56,7 +56,7 @@ def run(number):
     for idx, ans in enumerate(answer):
         rmsd = ans[0]
         best_mol = ans[1]
-        pdb_id = old_dir_names[idx]
+        pdb_id = pdb_id_list[idx]
         while True:
             user_input = input('\nInput the mol number of Exercise_%s:' % (idx+1))
             if user_input in answer_area:
